#ifndef MCMC_INCLUDE
#define MCMC_INCLUDE
/*------------------------------------------------------
 Maximum likelihood estimation 
 of migration rate  and effectice population size
 using a Metropolis-Hastings Monte Carlo algorithm                            
 -------------------------------------------------------                        
 M C M C   R O U T I N E S 
 
 Markov Monte Carlo stuff: treechange, acceptance
 
 
 Peter Beerli 1996, Seattle
 beerli@csit.fsu.edu
 
Copyright 2001 Peter Beerli and Joseph Felsenstein
 
$Id: mcmc.h,v 1.6 2003/11/04 16:12:09 beerli Exp $
-------------------------------------------------------*/

extern long tree_update (world_fmt * world, long g);
extern void free_timevector (timelist_fmt * timevector);
#endif
